@@ -28,9 +28,7 @@ describe 'tripleo::profile::base::cinder::volume' do
     end
 
     let(:pre_condition) do
-      "
-        class { '::tripleo::profile::base::cinder': step => #{params[:step]}, oslomsg_rpc_hosts => ['127.0.0.1'] }
-      "
+      "class { '::tripleo::profile::base::cinder': step => #{params[:step]}, oslomsg_rpc_hosts => ['127.0.0.1'] }"
     end
 
     context 'with step less than 4' do
@@ -177,7 +175,6 @@ describe 'tripleo::profile::base::cinder::volume' do
           params.merge!({
             :cinder_enable_rbd_backend   => true,
             :cinder_enable_iscsi_backend => false,
-            :cinder_rbd_client_name      => 'openstack'
           })
         end
         it 'should configure only ceph' do
@@ -189,8 +186,18 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to contain_class('cinder::backends').with(
             :enabled_backends => ['tripleo_ceph']
           )
-          is_expected.to contain_exec('exec-setfacl-openstack-cinder')
-          is_expected.to contain_exec('exec-setfacl-openstack-cinder-mask')
+        end
+        context 'additional rbd pools' do
+          # The list of additional rbd pools is not an input, but instead comes
+          # from hiera. Step 4's hiera data doesn't define additional RBD pools,
+          # so test the feature by defining extra pools in step 5 (see
+          # ../fixtures/hieradata/step5.yaml).
+          let(:params) { { :step => 5 } }
+          it 'should configure additional rbd backends' do
+            is_expected.to contain_class('cinder::backends').with(
+              :enabled_backends => ['tripleo_ceph', 'tripleo_ceph_foo', 'tripleo_ceph_bar']
+            )
+          end
         end
       end
 
